@@ -77,7 +77,8 @@ def create(ctx, name):
         tapd.set_iteration_id(iteration_id)
 
         excel = utils.Excel(utils.TEMPLATE_XLS, tapd)
-        excel.set_sheet_name(iteration_name)
+        # Excel Sheet 表面最长只能 31 个字符，超出会自动截断，并提示内容丢失
+        excel.set_sheet_name(iteration_name[:25] + (iteration_name[:25] and '...'))
 
         # 将迭代信息存储在用例表的A1单元格，方便后面上传用例使用
         excel.set_iteration_meta_info({
